@@ -4,25 +4,29 @@
 #' 
 #' @description This function interfaces the Global Runoff Data Centre database which provides river discharge data for about 9000 sites over 157 countries.
 #' 
-#' @param stationID Station ID number, it should be in the range [1104150,6990700]
-#' 
-#' @param lonMin Minimum latitude of bounding box
-#' @param lonMax Maximum latitude of bounding box
-#' @param latMin Minimum longitude of bounding box
-#' @param latMax Maximum longitude of bounding box 
-#' 
+#' @param bbox bounding box, a list made of 4 elements: minimum longitude (lonMin), minimum latitude (latMin), maximum longitude (lonMax), maximum latitude (latMax)  
+#' @param stationID Station ID number, it should be in the range [1104150,6990700] 
 #' @param mdDescription boolean value. Default is FALSE (no description is printed)
+#' @param metadataColumn name of the column to filter
+#' @param entryValue value to look for in the column named metadataColumn
 #' 
 #' @return list of stations within the bounding box
 #' 
 #' @export
 #' 
-#' @examples 
-#' GRDCCatalogue(lonMin=-3.82,lonMax=-3.63,latMin=52.43,latMax=52.52)
+#' @examples
+#' # Retrieve the whole catalogue
+#' # GRDCCatalogue()
+#' 
+#' # Define a bounding box
+#' # bbox <- list(lonMin=-3.82,latMin=52.41,lonMax=-3.63,latMax=52.52)
+#' 
+#' # Filter the catalogue
+#' # GRDCCatalogue(bbox)
 #' 
 
-GRDCCatalogue <- function(stationID=NULL,
-                          lonMin=-180,lonMax=+180,latMin=-90,latMax=+90,
+GRDCCatalogue <- function(bbox = NULL, stationID = NULL, 
+                          metadataColumn=NULL, entryValue=NULL,
                           mdDescription=FALSE){
 
   # Retrieve the catalogue
@@ -35,19 +39,57 @@ GRDCCatalogue <- function(stationID=NULL,
     grdcSelected <- grdcAll
   }
   
-  grdcSelectedBB <- subset(grdcSelected, (grdcSelected$lat <= latMax & grdcSelected$lat >= latMin & grdcSelected$lon <= lonMax & grdcSelected$lon >= lonMin) )
+  if (!is.null(bbox)){
     
-  if (mdDescription==FALSE){ 
+    lonMin <- bbox$lonMin
+    lonMax <- bbox$lonMax
+    latMin <- bbox$latMin
+    latMax <- bbox$latMax
     
-    grdcTable <- grdcSelectedBB    
+  }else{    
+    
+    lonMin <- -180
+    lonMax <- +180
+    latMin <- -90
+    latMax <- +90
+    
+  }
   
+  grdcSelectedBB <- subset(grdcSelected, (grdcSelected$lat <= latMax & grdcSelected$lat >= latMin & grdcSelected$lon <= lonMax & grdcSelected$lon >= lonMin) )  
+  
+  if ( !is.null(metadataColumn) & !is.null(entryValue) ){
+    
+    if (metadataColumn %in% names(grdcSelectedBB)){
+      
+      grdcTable <- grdcSelectedBB[which(grdcSelectedBB[,metadataColumn] == entryValue),]
+      
+    }else{
+      
+      message("metadataColumn should be one of the columns of the catalogue")
+      
+    }    
+    
   }else{
+    
+    grdcTable <- grdcSelectedBB
+    
+  } 
+  
+  row.names(grdcTable) <- NULL
+  names(grdcTable)[5] <- "id"
+  names(grdcTable)[7] <- "name"
+  names(grdcTable)[9]  <- "Latitude"
+  names(grdcTable)[10] <- "Longitude"
+    
+  if (mdDescription==TRUE){
+    
     temp <- system.file("GRDC/GRDC_legend.csv", package = 'hddtools')
     grdcLegend <- read.csv(temp, header=F)
     
-    grdcTable <- cbind(grdcLegend,t(grdcSelectedBB))
+    grdcTable <- cbind(grdcLegend,t(grdcTable))
     row.names(grdcTable) <- NULL 
     grdcTable$V1 <- NULL
+    
   }  
   
   return(grdcTable)
@@ -61,6 +103,7 @@ GRDCCatalogue <- function(stationID=NULL,
 #' @description This function interfaces the Global Runoff Data Centre monthly mean daily discharges database.
 #' 
 #' @param stationID 7 character number that identifies a station, GRDC station number is called "grdc no" in the catalogue.
+#' @param plotOption boolean to define whether to plot the results. By default this is set to TRUE.
 #' 
 #' @return The function returns a list of 3 tables: \describe{
 #'   \item{\strong{mddPerYear}}{This is a table containing mean daily discharges for each single year (n records, one per year). It is made of 7 columns which description is as follows:}\itemize{
@@ -98,40 +141,42 @@ GRDCCatalogue <- function(stationID=NULL,
 #' # x <- GRDCMonthlyTS(stationID=1107700)
 #' 
 
-GRDCMonthlyTS <- function(stationID){
+GRDCMonthlyTS <- function(stationID, plotOption=FALSE){
   
   options(warn=-1) 
   
-  # Retrieve look-up table
-  temp <- system.file("GRDC/GRDC_LTMMD.csv", package = 'hddtools')
-  grdcLTMMD <- read.csv(temp,sep="\t") 
-  
-  # Retrieve WMO region from catalogue
-  wmoRegion <- GRDCCatalogue(stationID)$wmo_reg
-  
-  # Retrieve ftp server location
-  zipFile <- as.character(grdcLTMMD[which(grdcLTMMD$WMO.Region==wmoRegion),
-                                    "Archive"])
-  
-  # create a temporary directory
-  td <- tempdir()
-  
-  # create the placeholder file
-  tf <- tempfile(tmpdir=td, fileext=".zip")
-  
-  # download into the placeholder file
-  download.file(zipFile, tf)
-  
-  # get the name of the file to unzip
-  fname <- paste("pvm_",stationID,".txt",sep="")
-  
-  # unzip the file to the temporary directory
-  unzip(tf, files=fname, exdir=td, overwrite=TRUE)
-  
-  # fpath is the full path to the extracted file
-  fpath = file.path(td, fname)  
+  temp <- GRDCCatalogue()  
     
-  if ( file.exists(fpath) ){
+  if ( temp[which(temp$grdc_no==stationID),"statistics"] == 1 ){
+    
+    # Retrieve look-up table
+    temp <- system.file("GRDC/GRDC_LTMMD.csv", package = 'hddtools')
+    grdcLTMMD <- read.csv(temp,sep="\t") 
+    
+    # Retrieve WMO region from catalogue
+    wmoRegion <- GRDCCatalogue(stationID = stationID)$wmo_reg
+    
+    # Retrieve ftp server location
+    zipFile <- as.character(grdcLTMMD[which(grdcLTMMD$WMO.Region==wmoRegion),
+                                      "Archive"])
+    
+    # create a temporary directory
+    td <- tempdir()
+    
+    # create the placeholder file
+    tf <- tempfile(tmpdir=td, fileext=".zip")
+    
+    # download into the placeholder file
+    download.file(zipFile, tf)
+    
+    # get the name of the file to unzip
+    fname <- paste("pvm_",stationID,".txt",sep="")
+    
+    # unzip the file to the temporary directory
+    unzip(tf, files=fname, exdir=td, overwrite=TRUE)
+    
+    # fpath is the full path to the extracted file
+    fpath = file.path(td, fname) 
     
     message("Station has monthly records")
     
@@ -168,11 +213,49 @@ GRDCMonthlyTS <- function(stationID){
       myTables[[i]] <- m
       
     }
+      
+    if ( plotOption == TRUE ){
+      
+      table1 <- myTables$mddPerYear
+      table2 <- myTables$mddAllPeriod
+      table3 <- myTables$mddPerMonth
+      
+      dummyTime <- seq(as.Date("2012-01-01"), 
+                       as.Date("2012-12-31"), 
+                       by="months") 
+      
+      plot(zoo(table3$MQ, order.by=dummyTime),
+           main=paste("Monthly statistics: ",
+                      GRDCCatalogue(stationID = stationID)$name,
+                      " (",GRDCCatalogue(stationID = stationID)$country_code,
+                      ")",sep=""),
+           type="l",ylim=c(min(table3$LQ),max(table3$HQ)),
+           xlab="",ylab="m3/s",xaxt = "n")
+      axis(1, at = dummyTime, labels = format(dummyTime, "%b"))
+      polygon(c(dummyTime,rev(dummyTime)), c(table3$HQ,rev(table3$LQ)),
+              col = "orange", 
+              lty = 0, 
+              lwd = 2, 
+              #border = ""
+              )
+      lines(zoo(table3$MQ, order.by=dummyTime), lty=2, lwd=3, col="red")
+      
+      legend("top", legend = c("Min-Max range", "Mean"), 
+             bty = "n",
+             col = c("orange", "red"),
+             lty = c(0, 2), lwd = c(0, 3),
+             pch = c(22, NA),
+             pt.bg = c("orange", NA),
+             pt.cex = 2)
+      
+    }
+    
+    return(myTables)
     
   }else{
+    
     message("Station does not have monthly records")
+    
   }
   
-  return(myTables)
-  
 }
